@@ -62,6 +62,7 @@ from .type_defs import (
     SubmitJobResponseTypeDef,
     UpdateComputeEnvironmentResponseTypeDef,
     UpdateJobQueueResponseTypeDef,
+    UpdatePolicyTypeDef,
 )
 
 if sys.version_info >= (3, 9):
@@ -387,7 +388,8 @@ class BatchClient(BaseClient):
         state: CEStateType = ...,
         unmanagedvCpus: int = ...,
         computeResources: "ComputeResourceUpdateTypeDef" = ...,
-        serviceRole: str = ...
+        serviceRole: str = ...,
+        updatePolicy: "UpdatePolicyTypeDef" = ...
     ) -> UpdateComputeEnvironmentResponseTypeDef:
         """
         Updates an Batch compute environment.
